@@ -45,11 +45,11 @@ class Toucan:
     tc_params = {}
     small_apps = []
 
-    def __init__(self, url, login, mode="prod"):
+    def __init__(self, url, username, password, mode="prod"):
         self.url_base = url
         host = url.partition("://")[2]
         self.__url_name = host.partition(".")[0]
-        self.login = login
+        self.login = {"username": username, "password": password}
         self.mode = mode
         try:
             if self.mode == "debug":
@@ -78,12 +78,9 @@ class Toucan:
         if self.mode == "debug":
             print("user logged")
 
-    def get_headers(self):
-        return {"authorization": f"Bearer {self.__token}"}
-
     def __request_small_apps(self):
         req = requests.get(
-            f"{self.url_api}/{self.__url_small_apps}", headers=self.get_headers()
+            f"{self.url_api}/{self.__url_small_apps}", headers=self.__get_headers()
         )
         req.raise_for_status()
         return req.json()
@@ -100,6 +97,117 @@ class Toucan:
         jsonConf = json.loads(res)
         return jsonConf
 
+    def __request_user(self):
+        req = requests.post(f"{self.url_api}/{self.__url_login}", json=self.login)
+        req.raise_for_status()
+        return req.json()
+
+    def __createFolder(self, name):
+        try:
+            os.makedirs(name)
+            print(f"Successfully created the directory {name}")
+        except OSError:
+            print(f"Directory {name} already exist")
+
+    def __calc_report_id(self, currentId, ids):
+        calcId = currentId
+        if ids is not None and 0 in ids:
+            calcId += int(ids.get(0))
+        return calcId
+
+    def __filterReport(self, reports, reportName):
+        resReport = [{"id": 0, "entityName": "default"}]
+        if reportName is None:
+            return reports
+        if not reports or len(reports) == 0:
+            return resReport
+        found = self.get_report_by_name(reports, reportName)
+        if found:
+            resReport = [found]
+        return resReport
+
+    def __generateUrls(self, app_name, config, reports, ids):
+        arr = []
+        if self.mode == "debug":
+            print("Get app slides")
+        slides = config.get("slides")
+        if self.mode == "debug":
+            print("Get app Home")
+        home = config.get("home")
+        if home is not None and "skipToReport" in home:
+            arr.append(
+                {
+                    "url": f"{self.url_base}/{app_name}",
+                    "selector": self.get_dashboard_selector(),
+                    "name": "dashboard",
+                }
+            )
+            if self.mode == "debug":
+                print("Add New dashboard to url list")
+        else:
+            arr.append(
+                {
+                    "url": f"{self.url_base}/{app_name}",
+                    "selector": ".report-execsum",
+                    "name": "dashboard",
+                }
+            )
+            if self.mode == "debug":
+                print("Add Old dashboard to url list")
+        if self.mode == "debug":
+            print("Generate all url from config")
+        for report in reports:
+            if "id" in report and "entityName" in report:
+                for slide in slides:
+                    if "parent_id" in slide and "id" in slide and "title" in slide:
+                        name = self.generate_screenshot_name(slide, report)
+                        rId = self.__calc_report_id(report.get("id"), ids)
+                        if self.mode == "debug":
+                            print("Generate url for", name)
+                        arr.append(
+                            {
+                                "url": f"{self.url_base}/{app_name}?report={rId}&dashboard={rId}&slide={slide.get('id')}",
+                                "selector": ".tc-slide__content, .tc-story",
+                                "name": name,
+                            }
+                        )
+        return arr
+
+    def __get_headers(self):
+        return {"authorization": f"Bearer {self.__token}"}
+
+    def embed_small_app_slide(self, small_app, slide, hosts=None):
+        allowedHosts = (
+            hosts
+            if hosts
+            else [
+                os.environ.get("PUBLIC_PROXY_API", ""),
+                os.environ.get("JUPYTERHUB_URL", ""),
+            ]
+        )
+        uid = str(uuid.uuid4())
+        data = {
+            "allowedHosts": allowedHosts,
+            "expirationDate": None,
+            "layout": {
+                "type": "single",
+                "content": {"path": f"slides[?id==`{slide}`]", "variables": {}},
+            },
+            "paths": [f"slides[?id==`{slide}`]"],
+            "public": False,
+            "smallApp": small_app,
+            "uid": uid,
+            "variables": {},
+        }
+        req = requests.post(
+            f"{self.url_api}/{self.__url_embed}",
+            headers=self.__get_headers(),
+            json=data,
+        )
+        req.raise_for_status()
+        url = f"{self.url_base}/embedLauncher.js?id={uid}&token={self.__token}"
+        display(HTML(f'<script async src="{url}" type="text/javascript"></script>'))
+
     def craft_toucan_embed_token(
         self,
         username: str,
@@ -124,19 +232,7 @@ class Toucan:
             payload, self.__TOUCAN_EMBED_ENCRYPTION_KEY, algorithm="HS256"
         ).decode("utf8")
 
-    def __request_user(self):
-        req = requests.post(f"{self.url_api}/{self.__url_login}", json=self.login)
-        req.raise_for_status()
-        return req.json()
-
-    def __createFolder(self, name):
-        try:
-            os.makedirs(name)
-            print(f"Successfully created the directory {name}")
-        except OSError:
-            print(f"Directory {name} already exist")
-
-    def dashboardSelector(self):
+    def get_dashboard_selector(self):
         statusApp = self.get_version()
         version = statusApp["frontVersion"]
         if version == "v64.0.0":
@@ -144,55 +240,8 @@ class Toucan:
         else:
             return ".small-app-home__content"
 
-    def __generateUrls(self, app_name, config, reports, ids):
-        arr = []
-        if self.mode == "debug":
-            print("Get app slides")
-        slides = config.get("slides")
-        if self.mode == "debug":
-            print("Get app Home")
-        home = config.get("home")
-        if home is not None and "skipToReport" in home:
-            arr.append(
-                {
-                    "url": f"{self.url_base}/{app_name}",
-                    "selector": self.dashboardSelector(),
-                    "name": "dashboard",
-                }
-            )
-            if self.mode == "debug":
-                print("Add New dashboard to url list")
-        else:
-            arr.append(
-                {
-                    "url": f"{self.url_base}/{app_name}",
-                    "selector": ".report-execsum",
-                    "name": "dashboard",
-                }
-            )
-            if self.mode == "debug":
-                print("Add Old dashboard to url list")
-        if self.mode == "debug":
-            print("Generate all url from config")
-        for report in reports:
-            if "id" in report and "entityName" in report:
-                for slide in slides:
-                    if "parent_id" in slide and "id" in slide and "title" in slide:
-                        name = self.generateScreenShotName(slide, report)
-                        rId = self.__calcReportId(report.get("id"), ids)
-                        if self.mode == "debug":
-                            print("Generate url for", name)
-                        arr.append(
-                            {
-                                "url": f"{self.url_base}/{app_name}?report={rId}&dashboard={rId}&slide={slide.get('id')}",
-                                "selector": ".tc-slide__content, .tc-story",
-                                "name": name,
-                            }
-                        )
-        return arr
-
     def get_version(self):
-        reqApi = requests.get(f"{self.url_api}", headers=self.get_headers())
+        reqApi = requests.get(f"{self.url_api}", headers=self.__get_headers())
         reqApi.raise_for_status()
         result = reqApi.json()
         reqApp = requests.get(f"{self.url_base}/{self.__url_tc_app_version}")
@@ -203,22 +252,23 @@ class Toucan:
 
     def get_app_config(self, app_name):
         req = requests.get(
-            f"{self.url_api}/{app_name}/{self.__url_config}", headers=self.get_headers()
+            f"{self.url_api}/{app_name}/{self.__url_config}",
+            headers=self.__get_headers(),
         )
         req.raise_for_status()
         return req.json()
 
     def get_app_data(self, app_name):
         req = requests.get(
-            f"{self.url_api}/{app_name}/{self.__url_data}", headers=self.get_headers()
+            f"{self.url_api}/{app_name}/{self.__url_data}", headers=self.__get_headers()
         )
         req.raise_for_status()
         return req.json()
 
-    def get_app_reportsIds(self, app_name):
+    def get_app_reports_ids(self, app_name):
         req = requests.get(
             f"{self.url_api}/{app_name}/{self.__url_reports}/{self.__ur_ids}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
         )
         req.raise_for_status()
         return req.json()
@@ -226,14 +276,14 @@ class Toucan:
     def get_app_reports(self, app_name):
         req = requests.get(
             f"{self.url_api}/{app_name}/{self.__url_reports}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
         )
         req.raise_for_status()
         return req.json()
 
     def get_users(self):
         req = requests.get(
-            f"{self.url_api}/{self.__url_users}", headers=self.get_headers()
+            f"{self.url_api}/{self.__url_users}", headers=self.__get_headers()
         )
         req.raise_for_status()
         return req.json()
@@ -324,7 +374,7 @@ class Toucan:
 
         req = requests.put(
             f"{self.url_api}/{app_name}/{self.__url_config}{config_name}?stage={stage}{formatFile}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
             files=files,
             data=data,
         )
@@ -358,7 +408,7 @@ class Toucan:
 
         req = requests.get(
             f"{self.url_api}/{app_name}/{self.__url_config}{config_name}?stage={stage}{formatFile}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
         )
         req.raise_for_status()
         return req
@@ -378,7 +428,7 @@ class Toucan:
         force_str = "true" if force else "false"
         req = requests.post(
             f"{self.url_api}/{app_name}/{self.__url_config}/pull?force={force_str}&stage={stage}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
             json={"operations": operations},
         )
         req.raise_for_status()
@@ -387,7 +437,7 @@ class Toucan:
     def get_data(self, app_name, domain, stage="staging"):
         req = requests.get(
             f"{self.url_api}/{app_name}/domain/{domain}?stage={stage}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
         )
         req.raise_for_status()
         s_data = str(req.content, "utf-8")
@@ -396,7 +446,7 @@ class Toucan:
     def get_metadata(self, app_name, stage="staging"):
         req = requests.get(
             f"{self.url_api}/{app_name}/metadata?stage={stage}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
         )
         req.raise_for_status()
         return req.json()
@@ -404,41 +454,11 @@ class Toucan:
     def create_small_app(self, app_name, id_app=None):
         body = {"name": app_name, "id": id_app if id_app else app_name}
         req = requests.post(
-            f"{self.url_api}/small-apps", headers=self.get_headers(), json=body
+            f"{self.url_api}/small-apps", headers=self.__get_headers(), json=body
         )
         req.raise_for_status()
         return req.json()
 
-    def embed_small_app_slide(self, small_app, slide, hosts=None):
-        allowedHosts = (
-            hosts
-            if hosts
-            else [
-                os.environ.get("PUBLIC_PROXY_API", ""),
-                os.environ.get("JUPYTERHUB_URL", ""),
-            ]
-        )
-        uid = str(uuid.uuid4())
-        data = {
-            "allowedHosts": allowedHosts,
-            "expirationDate": None,
-            "layout": {
-                "type": "single",
-                "content": {"path": f"slides[?id==`{slide}`]", "variables": {}},
-            },
-            "paths": [f"slides[?id==`{slide}`]"],
-            "public": False,
-            "smallApp": small_app,
-            "uid": uid,
-            "variables": {},
-        }
-        req = requests.post(
-            f"{self.url_api}/{self.__url_embed}", headers=self.get_headers(), json=data
-        )
-        req.raise_for_status()
-        url = f"{self.url_base}/embedLauncher.js?id={uid}&token={self.__token}"
-        display(HTML(f'<script async src="{url}" type="text/javascript"></script>'))
-
     def load_operations(
         self,
         app_name,
@@ -455,7 +475,7 @@ class Toucan:
         notificationStr = "true" if notification else "false"
         req = requests.post(
             f"{self.url_api}/{app_name}/{self.__url_config}/operations?notify={notificationStr}&stage={stage}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
             json={"operations": operations},
         )
         req.raise_for_status()
@@ -464,7 +484,7 @@ class Toucan:
     def load_conf(self, app_name, stage="staging"):
         req = requests.post(
             f"{self.url_api}/{app_name}/{self.__url_load}?stage={stage}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
         )
         req.raise_for_status()
         return req.json()
@@ -472,16 +492,12 @@ class Toucan:
     def release_conf(self, app_name, stage="staging"):
         req = requests.post(
             f"{self.url_api}/{app_name}/{self.__url_release}?stage={stage}",
-            headers=self.get_headers(),
+            headers=self.__get_headers(),
         )
         req.raise_for_status()
         return req.json()
 
-    def screenshotsAppAll(self):
-        for app in self.small_apps:
-            self.screenshotsApp(app)
-
-    def getReportByName(self, reports, reportName):
+    def get_report_by_name(self, reports, reportName):
         reportFound = None
         if not reports or len(reports) == 0:
             return reportFound
@@ -495,53 +511,40 @@ class Toucan:
                 reportFound = report
         return reportFound
 
-    def generateScreenShotName(self, slide, report):
+    def screenshots_app_all(self):
+        for app in self.small_apps:
+            self.screenshots_app(app)
+
+    def generate_screenshot_name(self, slide, report):
         title = slide.get("title", "noTitle")
         title = "".join(x for x in title if x.isalnum())
         name = report.get("entityName", "noEntity")
         name = "".join(x for x in name if x.isalnum())
         return f"{name}_{title}"
 
-    def __calcReportId(self, currentId, ids):
-        calcId = currentId
-        if ids is not None and 0 in ids:
-            calcId += int(ids.get(0))
-        return calcId
-
-    def generateFolderName(self, app_name):
+    def generate_folder_name(self, app_name):
         today = datetime.date.today().strftime("%Y_%m_%d")
         return f"{today}/{self.__url_name}/{app_name}"
 
-    def isAppAllowed(self, app_name):
+    def is_app_allowed(self, app_name):
         res = False
         for small_app in self.small_apps:
             if small_app.get("id") == app_name:
                 res = True
         return res
 
-    def __filterReport(self, reports, reportName):
-        resReport = [{"id": 0, "entityName": "default"}]
-        if reportName is None:
-            return reports
-        if not reports or len(reports) == 0:
-            return resReport
-        found = self.getReportByName(reports, reportName)
-        if found:
-            resReport = [found]
-        return resReport
-
-    def screenshotsApp(self, app_name, reportName=None, fullSize=False):
+    def screenshots_app(self, app_name, reportName=None, fullSize=False):
         if self.mode == "debug":
             print("Generate screenshots for", app_name)
-        if self.isAppAllowed(app_name):
-            folderName = self.generateFolderName(app_name)
+        if self.is_app_allowed(app_name):
+            folderName = self.__generate_folder_name(app_name)
             self.__createFolder(folderName)
             if self.mode == "debug":
                 print("Get app config")
             config = self.get_app_config(app_name)
             ids = None
             try:
-                ids = self.get_app_reportsIds(app_name)
+                ids = self.get_app_reports_ids(app_name)
             except requests.exceptions.RequestException:
                 print("Cannot get report ids")
             reportsAll = self.get_app_reports(app_name)
